@@ -239,7 +239,7 @@ def _PyScons(env, target, source, scons, options="-Q", sig_options="", clean = T
     cmd = "scons %s %s -f%s %s" % (options, sig_options, scons, args)
     cleancmd = cmd + " --clean"
 
-    exe = os.path.join(basename, "EXECUTE")
+    exe = os.path.join(tempdir, "EXECUTE")
     file = open(exe, 'w')
     print >>file, "#!/bin/bash"
     print >>file, cmd + " $*"
